#!/bin/bash
#
# Generate NFPA.mp for given hazard levels

HEALTH=$1
FIRE=$2
REACT=$3
OX=$4
W=$5

REDIRECT=0 # if != 0, then print directly to OFILE
OFILE="NFPA.mp"

# stdout redirection from Advanced Bash Scripting Guide
# http://tldp.org/LDP/abs/html/x16355.html#REASSIGNSTDOUT
if [ $REDIRECT -ne 0 ]
then
    exec 6>&1  # Link file descriptor #6 with stdout.
               # Saves stdout.
    # stdout replaced with file "logfile.txt".
    exec > $OFILE
fi

echo "verbatimtex

\font\bigfont=cmss17 at 50pt
\font\medfont=cmss17 at 25pt
\font\smfont=cmss17 at 20pt
\bigfont

% center two hboxes (containing e.g. \OX and \W)
\def\vert#1#2{\vbox{\halign{\hfil##\hfil\cr
\hbox{#1}\cr
\hbox{#2}\cr}}}

% strikethrough (or strikeout) from Chapter 21 of the TeXbook
% the height of the strikeout has been raised from 0.8 to 0.9ex
% to make it look nicer when escaping a purely capital letter (W).
\def\sout#1{{%
  \setbox0=\hbox{#1}%
  \dimen0 0.9ex\dimen1\dimen0\advance\dimen1 by 0.4pt
  \rlap{\leaders\hrule height \dimen1 depth -\dimen0\hskip\wd0}%
  \box0
}}

\def\OX{{OX}}
\def\W{{\sout{W}}}

etex

%% NFPA values :
% set in the call to mpost, e.g.
% $ mpost 'input NFPA.mp; input NFPA_c.mp'
picture h,f,r,o;
h := btex $HEALTH etex;
f := btex $FIRE etex;
r := btex $REACT etex;"

if [ "$OX" == "y" ] && [ "$W" == "y" ]
then
    echo "o := btex {\smfont \vert{\OX}{\W}} etex;"
elif [ "$OX" == "y" ]
then
    echo "o := btex {\medfont \OX} etex;"
elif [ "$W" == "y" ]
then
    echo "o := btex {\medfont \W} etex;"
fi

if [ $REDIRECT -ne 0 ]
then
    # Restore stdout and close file descriptor #6.
    exec 1>&6 6>&-
fi

exit 0
