"""
From pyOpenSSL examples with a bit of wrapping.
Create certificates and private keys for the 'simple' example.
"""

from OpenSSL import crypto
from certgen import *   # yes yes, I know, I'm lazy

def get_cert_filenames(server_name) :
    """
    Generate private key and certification filesnames.
    mk_certs(server_name) -> (pkey_filename, cert_filename)
    """
    pkey_file = '%s.pkey' % server_name
    cert_file = '%s.cert' % server_name
    return (pkey_file, cert_file)

def mk_certs(server_name) :
    """
    Generate private key and certification files.
    mk_certs(server_name) -> (pkey_filename, cert_filename)
    """
    pkey_file,cert_file = get_cert_filenames(server_name)
    
    cakey = createKeyPair(TYPE_RSA, 1024)
    careq = createCertRequest(cakey, CN='Certificate Authority')
    cacert = createCertificate(careq, (careq, cakey), 0, (0, 60*60*24*365*5)) # five years
    open(pkey_file, 'w').write(crypto.dump_privatekey(crypto.FILETYPE_PEM, cakey))
    open(cert_file, 'w').write(crypto.dump_certificate(crypto.FILETYPE_PEM, cacert))

if __name__ == "__main__" :
    import sys

    mk_certs(sys.argv[1])

